@@ -2,7 +2,7 @@
 
 set -eu
 
-if [ -e ./mmdebstrap -a -e ./taridshift -a -e ./tarfilter -a -e ./coverage.py ]; then
+if [ -e ./mmdebstrap ]; then
 	TMPFILE=$(mktemp)
 	perltidy < ./mmdebstrap > "$TMPFILE"
 	ret=0
@@ -20,10 +20,11 @@ if [ -e ./mmdebstrap -a -e ./taridshift -a -e ./tarfilter -a -e ./coverage.py ];
 	fi
 
 	perlcritic --severity 4 --verbose 8 ./mmdebstrap
-
-	black --check ./taridshift ./tarfilter ./coverage.py
 fi
 
+[ -e ./tarfilter ] && black --check ./tarfilter
+[ -e ./coverage.py ] && black --check ./coverage.py
+
 mirrordir="./shared/cache/debian"
 
 if [ ! -e "$mirrordir" ]; then
@@ -113,4 +114,4 @@ END
 	echo
 fi
 
-rm shared/test.sh shared/tar1.txt shared/tar2.txt shared/pkglist.txt shared/doc-debian.tar.list shared/mmdebstrap shared/taridshift shared/tarfilter shared/proxysolver
+rm shared/test.sh shared/tar1.txt shared/tar2.txt shared/pkglist.txt shared/doc-debian.tar.list shared/mmdebstrap shared/tarfilter shared/proxysolver
